@@ -46,3 +46,24 @@ class SourceModelViewset(ModelViewSet):
             return Response(data=source.get_status(), status=status.HTTP_202_ACCEPTED)
 
         return Response(status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+
+    @action(detail=True, methods=["get"])
+    def property_values(self, request, pk):
+        """
+        Returns all distinct values of specified GET "property" params from
+        database for the specified source layer.
+
+        Note: if some record has no value for this property, None is contained in the
+        result list.
+        """
+        property_to_list = request.query_params.get("property")
+        if not property_to_list:
+            return Response(
+                {"error": 'Invalid "property" GET parameter'},
+                status=status.HTTP_400_BAD_REQUEST,
+            )
+
+        source = self.get_object()
+        result = source.get_layer().get_property_values(property_to_list)
+
+        return Response(result)
